.. _spkg_combinatorial_designs:

combinatorial_designs: Data from the Handbook of Combinatorial Designs
================================================================================

Description
-----------

Data for Combinatorial Designs. Current content:

-  The table of MOLS (10 000 integers) from the Handbook of
   Combinatorial Designs, 2ed.

License
-------

Public domain.


Upstream Contact
----------------

   None

Type
----

standard


Dependencies
------------


Version Information
-------------------

package-version.txt::

    20140630.p0


Equivalent System Packages
--------------------------

.. tab:: Arch Linux

   .. CODE-BLOCK:: bash

       $ sudo pacman -S sage-data-combinatorial_designs 


.. tab:: conda-forge

   .. CODE-BLOCK:: bash

       $ conda install sagemath-db-combinatorial-designs 



See https://repology.org/project/sagemath-combinatorial-designs/versions

However, these system packages will not be used for building Sage
because ``spkg-configure.m4`` has not been written for this package;
see :issue:`27330` for more information.

